from spark_auto_mapper.data_types.complex.complex_base import (
    AutoMapperDataTypeComplexBase,
)


class ExtensionBase(AutoMapperDataTypeComplexBase):
    """
    DO NOT USE DIRECTLY!  ALWAYS USE A SUB_CLASS.

    """
